*****************************************************************************
*																			*
*              Differentiation in Environmental Treatymaking:				*
* Measuring Provisions and How They Reshape The Depth-Participation Dilemma	*
*																			*
*				      Deborah Farias & Charles Roger 						*
*								 GEP, 2022									*
*****************************************************************************

*** Patterns of Differentiation in Environmental Treaties ***


** Figure 1: MEAs with Provisions for Differentiation

clear

use Figure_1.dta

graph twoway (bar mea_total protocol_total year, yaxis(2) ytitle("Share (%)") barwidth(7)) (line share year, yaxis(1) lp(dash) ytitle("Cumulative Total (Bars)", axis(2))), xlabel(1940(10)2010) xtitle("Year") legend(col(3))


** Figure 2: Number of State Ratifications, 2020

clear

use Figure_2.dta

graph bar diff total, over(rats, sort(ordvar))



*** Analysis: Revisiting the Depth-Participation Dilemma ***

clear

use FarRog_GEP_2022.dta


* Generate Variable "Depth"

gen depth = mon + enf + qtarget


* Main Regressions, Table 1

nbreg ratcount depth, robust

nbreg ratcount diff, robust

nbreg ratcount c.depth##i.diff, robust

nbreg ratcount c.depth##i.diff ass_all disp_set secr global gdmix pollution species nuclear habitat aget, robust


* Marginal Effects Estimates, Figure 3

margins, at(depth=(0 3) diff=(0 1)) vsquish
marginsplot, xdim(diff) bydim(depth) recast(bar) plotopts(barw(.8))



*** Note ***

* All vars (except diff) in FarRog_GEP_2022.dta from Bernauer et al. (2013) Is there a "Depth versus Participation" dilemma in international cooperation? Review of International Organizations, 8, 477-497. DOI: https://doi.org/10.1007/s11558-013-9165-1.
